#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dense-linear-algebra
version:              0.1.0.0
visibility:           public
id:                   dense-linear-algebra-0.1.0.0-KX75ukTjmOr9hol40Dsljp
key:                  dense-linear-algebra-0.1.0.0-KX75ukTjmOr9hol40Dsljp
license:              BSD-2-Clause
copyright:            2018 Author name here
maintainer:           Alexey Khudaykov <alexey.skladnoy@gmail.com>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
synopsis:
    Simple and incomplete pure haskell implementation of linear algebra

description:
    This library is simply collection of linear-algebra related modules
    split from statistics library.

category:             Math, Statistics, Numeric
abi:                  42afa3e284c45b964690a0524ac824e3
exposed:              True
exposed-modules:
    Statistics.Matrix Statistics.Matrix.Algorithms
    Statistics.Matrix.Function Statistics.Matrix.Mutable
    Statistics.Matrix.Types

import-dirs:          /usr/lib/ghc-9.6.6/site-local/dense-linear-algebra-0.1.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/dense-linear-algebra-0.1.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/dense-linear-algebra-0.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dense-linear-algebra
hs-libraries:         HSdense-linear-algebra-0.1.0.0-KX75ukTjmOr9hol40Dsljp
depends:
    base-4.18.2.1 deepseq-1.4.8.1
    math-functions-0.3.4.4-ELJYOCHeZCo3AbQJsZAY0E
    primitive-0.9.1.0-3wcULVX324m4b7zw32DKNg
    vector-0.13.2.0-KFVS0U8K6eML5O0P7tVbRi
    vector-algorithms-0.9.1.0-9Ue2SfpM5K34TbkhjzoJSP
    vector-binary-instances-0.2.5.2-HZgfLZ0BeRq7aeVKAymBpS
    vector-th-unbox-0.2.2-46hI3ZvaD54Cy71NpluF8R

haddock-interfaces:
    /usr/share/doc/haskell-dense-linear-algebra/html/dense-linear-algebra.haddock

haddock-html:         /usr/share/doc/haskell-dense-linear-algebra/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

